# Napistu Python Library

[![PyPI version](https://badge.fury.io/py/napistu.svg)](https://badge.fury.io/py/napistu)
[![Documentation Status](https://readthedocs.org/projects/napistu/badge/?version=latest)](https://napistu.readthedocs.io/en/latest/?badge=latest)
[![CI](https://github.com/napistu/napistu-py/actions/workflows/ci.yml/badge.svg)](https://github.com/napistu/napistu-py/actions/workflows/ci.yml)
[![Release](https://github.com/napistu/napistu-py/actions/workflows/release.yml/badge.svg)](https://github.com/napistu/napistu-py/actions/workflows/release.yml)
[![Deploy to Cloud Run](https://github.com/napistu/napistu-py/actions/workflows/deploy.yml/badge.svg)](https://github.com/napistu/napistu-py/actions/workflows/deploy.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This Python package hosts the majority of the algorithmic code for the [Napistu project](https://github.com/napistu/napistu).

## Setup

Napistu is available on [PyPI](https://pypi.org/project/napistu) so the recommended way to use it is just to pip install with:

```bash
pip install napistu
```

Alternatively, you can clone this repository and perform a local install. e.g., from this directory:

```bash
pip install .
```

## Documentation
- 📘 **Library Documentation**: [napistu.readthedocs.io](https://napistu.readthedocs.io)
- 🚸 **Project Documentation**: [napistu/wiki](https://github.com/napistu/napistu/wiki)

### Quick Links
- [Installation Guide](https://napistu.readthedocs.io/en/latest/installation.html)
- [API Reference](https://napistu.readthedocs.io/en/latest/api.html)
- [Usage Examples](https://napistu.readthedocs.io/en/latest/usage.html)
